# Generated by Django 3.0.4 on 2020-04-01 08:47

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('whisperer', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='webhook',
            name='additional_headers',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
    ]
