# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2019-05-30 07:10
from __future__ import unicode_literals

from django.conf import settings
import django.contrib.postgres.fields
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('whisperer', '0003_auto_20200505_0853'),
    ]

    operations = [
        migrations.AddField(
            model_name='WebhookEvent',
            name='retry_count',
            field=models.PositiveIntegerField(null=True),
        )
    ]
